#
# spec file for package florence
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           florence
Version:        0.6.3
Release:        6.2
Summary:        Extensible scalable on-screen virtual keyboard
License:        GFDL-1.2-only AND GPL-2.0-or-later
Group:          System/X11/Utilities
URL:            http://florence.sourceforge.net
Source0:        http://downloads.sourceforge.net/florence/%{name}-%{version}.tar.bz2
Source99:       florence-rpmlintrc
# PATCH-FIX-OPENSUSE florence-icondir.patch bnc#855529 dap.darkness@gmail.com -- Set correct svg icon directory to not breake the application
Patch0:         florence-icondir.patch
# PATCH-FIX-UPSTREAM florence-implicit-definitions.patch sf#florence#14 dimstar@opensuse.org -- Fix implicit definition of function wait()
Patch1:         florence-implicit-definitions.patch
# PATCH-FIX-UPSTREAM florence-buildfix.patch dimstar@opensuse.org -- Fix build system: link libflorence-1.0.la
Patch2:         florence-buildfix.patch
# PATCH-FIX-UPSTREAM florence-build-without-scrollkeeper.patch -- Fix build without scrollkeeper
Patch3:         florence-build-without-scrollkeeper.patch

BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
%if 0%{?suse_version} > 1500
BuildRequires:  python3-libxml2
%endif
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(atspi-2)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gnome-doc-utils)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xtst)

%description
Florence is an extensible scalable virtual keyboard for X11.
You need it if you can't use a real hardware keyboard, for
example because you are disabled, your keyboard is broken or
because you use a tablet PC, but you must be able to use a pointing
device (as a mouse, a trackball or a touchscreen).

Florence stays out of your way when you don't need it:
it appears on the screen only when you need it.
A Timer-based auto-click functionality is available
to help disabled people having difficulties to click.

%package -n libflorence-1_0-1
Summary:        Library files for %{name}
Group:          System/X11/Utilities

%description -n libflorence-1_0-1
Extensible scalable on-screen virtual keyboard.
This package contains libraries.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/X11
Requires:       %{name} = %{version}-%{release}

%description    devel
This package contains libraries and header files for
developing applications that use florence.

%lang_package

%prep
%setup -q
sed -i 's|Icon=@ICONDIR@/%{name}.svg|Icon=%{name}|g' data/%{name}.desktop.in.in
%patch -P 0
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1

%build
autoreconf -fiv
%configure \
    --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name *.la -delete
%suse_update_desktop_file -r %{name} Utility Accessibility
%find_lang %{name} %{?no_lang_C}

%post -n libflorence-1_0-1 -p /sbin/ldconfig

%postun -n libflorence-1_0-1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%license COPYING
%doc AUTHORS ChangeLog COPYING-DOCS NEWS README
%dir %{_datadir}/gnome/help/%{name}
%doc %{_datadir}/gnome/help/%{name}/C/
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}_applet.1%{?ext_man}
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/glib-2.0/schemas/org.%{name}.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%files -n libflorence-1_0-1
%defattr(-,root,root)
%{_libdir}/libflorence-1.0.so.*

%files devel
%defattr(-,root,root)
%dir %{_includedir}/florence-1.0
%{_includedir}/florence-1.0/florence.h
%{_libdir}/libflorence-1.0.so
%{_libdir}/pkgconfig/florence-1.0.pc

%files lang -f %{name}.lang

%changelog
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Prepare for RPM 4.20: patchN -> patch -P N.
* Wed Aug 18 2021 Dmitriy Perlow <dap.darkness@gmail.com>
- `BuildRequires: python3-libxml2` to fix Factory build.
- Purged useless macros from %%%%post(un).
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Jul  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add florence-build-without-scrollkeeper.patch : Fix build without
  scrollkeeper support, following this patch, drop
  rarian-scrollkeeper-compat BuildRequires and stop passing
  - -disable-scrollkeeper to configure, no longer needed nor used.
* Wed May 16 2018 dimstar@opensuse.org
- Add florence-buildfix.patch: Fix reference to libflorence, fixes
  also parallel build.
* Sat Apr  2 2016 zaitor@opensuse.org
- Update to version 0.6.3:
  + Many bug fixes
- Changes from version 0.6.2:
  + Fix gradients.
  + Remove deprecated GTK3 functions.
- Changes from version 0.6.1:
  + A lot of bug fixes.
  + Add commands to the dbus interface.
  + Add command line options to control the keyboard.
  + Move at-spi2 handling to a new process in order to avoid
    deadlocks.
  + Implement a floating icon for desktops with no systray.
- Remove la files, not needed in openSUSE.
- Disable parallel build, currently broken.
- Replace *-devel BuildRequires for their pkgconfig counterparts:
  + at-spi2-core-devel for pkgconfig(atspi-2).
  + libXtst-devel for pkgconfig(xtst).
  + librsvg2-devel for pkgconfig(librsvg-2.0).
- Drop pkgconfig(gstreamer-0.10) and add pkgconfig(gstreamer-1.0)
  BuildRequires, upstream ported to current gstreamer.
- Add pkgconfig(cairo), pkgconfig(gio-2.0), pkgconfig(gmodule-2.0),
  pkgconfig(x11) and pkgconfig(xext) BuildRequires: configure looks
  for them.
- Add new devel and lib subpackages.
- Handle new so files in post/postun.
- Pass --disable-static to configure since we do not need them.
- Rebase and simplify florence-icondir.patch.
- Add libtool BuildRequires and call autoreconf: needed, as
  florence-icondir.patch touches the build system.
- Add florence-implicit-definitions.patch: Do not use wait(), which
  is implicit defined and has no function.
* Sun Dec 15 2013 dap.darkness@gmail.com
- Added florence-icondir.patch: set correct svg icon directory in
  order to not broke the app (bnc#855529).
- Add florence-rpmlintrc: filter warnings for duplicate files in
  /usr/share/help/florence. Using fdupes could potentially cause
  link targets to end up in the -lang package, not being installed
  by default. As C lang help though is installed from the main
  package, there is a chance of breakage.
* Sat Sep 21 2013 zaitor@opensuse.org
- Add rarian-scrollkeeper-compat BuildRequires, due to
  gnome-doc-utils no longer pulling in scrollkeeper. Configure
  explicitly checks for scrollkeeper.
- Own %%{_datadir}/omf because of the above change.
* Sat Jul  6 2013 dap.darkness@gmail.com
- Initial build.
